// (C) Copyright 2002-2007 by Autodesk, Inc. 
//
// Permission to use, copy, modify, and distribute this software in
// object code form for any purpose and without fee is hereby granted, 
// provided that the above copyright notice appears in all copies and 
// that both that copyright notice and the limited warranty and
// restricted rights notice below appear in all supporting 
// documentation.
//
// AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS. 
// AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
// MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK, INC. 
// DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL BE
// UNINTERRUPTED OR ERROR FREE.
//
// Use, duplication, or disclosure by the U.S. Government is subject to 
// restrictions set forth in FAR 52.227-19 (Commercial Computer
// Software - Restricted Rights) and DFAR 252.227-7013(c)(1)(ii)
// (Rights in Technical Data and Computer Software), as applicable.

/////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// acrxEntryPoint.cpp illustrates use of the Associative Array API.
//
// Products: AutoCAD (and verticals) 2012 and higher
//
// Written by Philippe Leefsma - 2010 - Developer Technical Services
//     AutoCAD 2013+ -  
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////
#include "StdAfx.h"
#include "AssocArrayDemo.h"

#define szRDS _RXST("Adsk")

//----- ObjectARX EntryPoint
class CArxAssocArrayApp : public AcRxArxApp 
{

public:

	CArxAssocArrayApp () : AcRxArxApp () {}

	virtual AcRx::AppRetCode On_kInitAppMsg (void *pkt) 
	{
		// TODO: Load dependencies here

		// You *must* call On_kInitAppMsg here
		AcRx::AppRetCode retCode = AcRxArxApp::On_kInitAppMsg (pkt) ;
		
		// TODO: Add your initialization code here
		acutPrintf(L"\n ---   API   --- ");

		acutPrintf(L"\n  : ");

		acutPrintf(L"\n 1/  ARXRECTARRAY");
		acutPrintf(L"\n 2/  ARXARRAYMODIFY");
		acutPrintf(L"\n 3/  ARXARRAYEXPLODE"); 
		acutPrintf(L"\n 4/  ARXINFOARRAY"); 
		acutPrintf(L"\n ------------------------------------------ \n");

		return (retCode) ;
	}

	virtual AcRx::AppRetCode On_kUnloadAppMsg (void *pkt) 
	{
		// TODO: Add your code here

		// You *must* call On_kUnloadAppMsg here
		AcRx::AppRetCode retCode =AcRxArxApp::On_kUnloadAppMsg (pkt) ;

		// TODO: Unload dependencies here

		return (retCode) ;
	}

	virtual void RegisterServerComponents () {
	}


	// ----- AdskArxAssocArray._ARXRECTARRAY command
	static void AdskArxAssocArray_ARXRECTARRAY(void)
	{
		// Add your code for command AdskArxAssocArray._ARXRECTARRAY here
		Acad::ErrorStatus es = AssocArrayDemo::createRectangularArray();

		acedCommand(5005, L"_.ZOOM", RTSTR, L"_E", RTNONE);
	}

	// - AdskArxAssocArray._ARXRECTARRAYMODIF command (do not rename)
	static void AdskArxAssocArray_ARXARRAYMODIF(void)
	{
		// Add your code for command AdskArxAssocArray._ARXARRAYMODIF here
		AcDbObjectId id;
		ads_name name;
		ads_point pt;

		if(acedEntSel(L"\n  : ", name, pt) != RTNORM)
		{	
			return;
		}
			
		acdbGetObjectId(id, name); 
		
		Acad::ErrorStatus es = AssocArrayDemo::modifyArray(id);

		if(es == Acad::eInvalidInput)
			acutPrintf(L"\n   .   ...");
	}

	// - AdskArxAssocArray._ARXARRAYEXPLODE command (do not rename)
	static void AdskArxAssocArray_ARXARRAYEXPLODE(void)
	{
		// Add your code for command AdskArxAssocArray._ARXARRAYEXPLODE here
		AcDbObjectId id;
		ads_name name;
		ads_point pt;

		if(acedEntSel(L"\n  : ", name, pt) != RTNORM)
		{	
			return;
		}
			
		acdbGetObjectId(id, name); 
		
		Acad::ErrorStatus es = AssocArrayDemo::explodeArray(id);

		if(es == Acad::eInvalidInput)
			acutPrintf(L"\n   .   ...");
	}

	// - AdskArxAssocArray._ARXINFOARRAY command (do not rename)
	static void AdskArxAssocArray_ARXINFOARRAY(void)
	{
		// Add your code for command AdskArxAssocArray._ARXINFOARRAY here
		AcDbObjectId id;
		ads_name name;
		ads_point pt;

		if(acedEntSel(L"\n  : ", name, pt) != RTNORM)
		{	
			return;
		}
			
		acdbGetObjectId(id, name); 

		Acad::ErrorStatus es = AssocArrayDemo::infoArray(id);

		if(es == Acad::eInvalidInput)
			acutPrintf(L"\n   .   ...");
	}
} ;

//-----------------------------------------------------------------------------
IMPLEMENT_ARX_ENTRYPOINT(CArxAssocArrayApp)

ACED_ARXCOMMAND_ENTRY_AUTO(CArxAssocArrayApp, AdskArxAssocArray, _ARXRECTARRAY, ARXRECTARRAY, ACRX_CMD_TRANSPARENT, NULL)
ACED_ARXCOMMAND_ENTRY_AUTO(CArxAssocArrayApp, AdskArxAssocArray, _ARXARRAYMODIF, ARXARRAYMODIF, ACRX_CMD_TRANSPARENT, NULL)
ACED_ARXCOMMAND_ENTRY_AUTO(CArxAssocArrayApp, AdskArxAssocArray, _ARXARRAYEXPLODE, ARXARRAYEXPLODE, ACRX_CMD_TRANSPARENT, NULL)
ACED_ARXCOMMAND_ENTRY_AUTO(CArxAssocArrayApp, AdskArxAssocArray, _ARXINFOARRAY, ARXINFOARRAY, ACRX_CMD_TRANSPARENT, NULL)
